EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'RubyGems_DeleteGem',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes a Ruby Gem.'
GO

IF OBJECT_ID('[RubyGems_DeleteGem]') IS NOT NULL DROP PROCEDURE [RubyGems_DeleteGem]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [RubyGems_DeleteGem]
(
	@Feed_Id INT,
	@Gem_Name VARCHAR(100),
	@Version_Text VARCHAR(50),
	@Platform_Text VARCHAR(50),
	@LatestVersion_Text VARCHAR(50)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

		DECLARE @Gem_Id INT
		SET @Gem_Id = (SELECT [Gem_Id] FROM [RubyGems] WITH (UPDLOCK) WHERE [Feed_Id] = @Feed_Id AND [Gem_Name] = @Gem_Name)

		DELETE
		  FROM [RubyGemVersions]
		 WHERE [Gem_Id] = @Gem_Id
		   AND [Version_Text] = @Version_Text
		   AND [Platform_Text] = @Platform_Text

		IF NOT EXISTS(SELECT * FROM [RubyGemVersions] WITH (UPDLOCK) WHERE [Gem_Id] = @Gem_Id)
		BEGIN

			DELETE
			  FROM [RubyGems]
			 WHERE [Gem_Id] = @Gem_Id

		END
		ELSE IF @LatestVersion_Text IS NOT NULL
		BEGIN

			UPDATE [RubyGems]
			   SET [LatestVersion_Text] = @LatestVersion_Text
			 WHERE [Gem_Id] = @Gem_Id

		END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [RubyGems_DeleteGem] TO [ProGetUser_Role]
GO